# -*- coding: utf-8 -*-
#
# Copyright (c) 2012-2020 Virtual Cable S.L.U.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright notice,
#      this list of conditions and the following disclaimer in the documentation
#      and/or other materials provided with the distribution.
#    * Neither the name of Virtual Cable S.L. nor the names of its contributors
#      may be used to endorse or promote products derived from this software
#      without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""
@author: Adolfo Gómez, dkmaster at dkmon dot com
"""
import logging

from uds.core.util import states

from uds.models import CalendarAction, getSqlDatetime
from uds.core.jobs import Job

logger = logging.getLogger(__name__)


class ScheduledAction(Job):
    frecuency = 29  # Frecuncy for this job
    friendly_name = 'Scheduled action runner'

    def run(self) -> None:
        configuredAction: CalendarAction
        for configuredAction in CalendarAction.objects.filter(
            service_pool__service__provider__maintenance_mode=False,  # Avoid maintenance
            service_pool__state=states.servicePool.ACTIVE,  # Avoid Non active pools
            next_execution__lt=getSqlDatetime(),
        ).order_by('next_execution'):
            logger.info(
                'Executing calendar action %s.%s (%s)',
                configuredAction.service_pool.name,
                configuredAction.calendar.name,
                configuredAction.action,
            )
            try:
                configuredAction.execute()
            except Exception:
                logger.exception(
                    'Got an exception executing calendar access action: %s',
                    configuredAction,
                )
